@@ -3,12 +3,17 @@
 #'
 #' @description
 #' mmiGEE is a multimodel inference approach evaluating the relative
-#' importance of predictors used in \code{\link{GEE}}. It performs automatically
+#' importance of predictors used in \code{\link{GEE}}.
+#'
+#'  @details It performs automatically
 #' generated model selection and creates a model
 #' selection table according to the approach of multi-model inference
 #' (Burnham & Anderson, 2002). QIC is used to obtain model
 #' selection weights and to rank the models. Moreover, mmiGEE calculates relative
 #' variable importance of a given model.
+#' Finally, this function requires that \strong{all predictor variables
+#' be continuous}.
+#'
 #'
 #' @details Calculates the relative importance of each variable
 #' using multi-model inference methods in a Generalized Estimating Equations
@@ -57,6 +62,8 @@
 #'
 #' mmi<-mmiGEE(mgee,birthwt)
 #'}
+#' @importFrom stats update reformulate drop.terms model.matrix as.formula terms
+#' @importFrom rje powerSetMat
 #' @export
 #'
 #'
@@ -81,18 +88,18 @@ mmiGEE<-function(object,data, trace = FALSE){
   }
 
   # Parameter: varnames, p
-  X<-model.matrix(formula,data)
+  X<-stats::model.matrix(formula,data)
   if(dimnames(X)[[2]][1]!="(Intercept)") {
-    formula<-update(formula, ~ . + 1)
-    X<-model.matrix(formula,data)
+    formula <- stats::update(formula, ~ . + 1)
+    X<-stats::model.matrix(formula,data)
   }
   nvar<-dim(X)[2]
   varnames<-dimnames(X)[[2]][-1]
   p<-dim(X)[2]-1 # nvar-1 (without intercept)
 
-  pset<-rje::powerSetMat(p)
-  ip<-dim(pset)[1]
-  t<-terms(formula)
+  pset <- rje::powerSetMat(p)
+  ip <- dim(pset)[1]
+  t <- stats::terms(formula)
   # Run every model and calculate QIC (multimodel inference)
   coef.vec<-matrix(NA,ip,nvar)
   df<-rep(NA,ip)
@@ -100,12 +107,12 @@ mmiGEE<-function(object,data, trace = FALSE){
   QIC<-rep(NA,ip)
   for (i in 1:ip) {
     if(sum(pset[i,])!=0 & sum(pset[i,])!=p){
-      t1<-drop.terms(t,which(pset[i,]==0), keep.response = TRUE)
-      formula1<-reformulate(attr(t1, "term.labels"), formula[[2]])
+      t1 <- stats::drop.terms(t,which(pset[i,]==0), keep.response = TRUE)
+      formula1<- stats::reformulate(attr(t1, "term.labels"), formula[[2]])
       formulae<-formula1
     }
     if(sum(pset[i,])==p) formulae<-formula
-    if(sum(pset[i,])==0) formulae<-as.formula(paste(formula[[2]],"~1"))
+    if(sum(pset[i,])==0) formulae<-stats::as.formula(paste(formula[[2]],"~1"))
 
     m0<-suppressWarnings({
       GEE(formulae,family,data,coord,corstr=corstr,
@@ -115,7 +122,7 @@ mmiGEE<-function(object,data, trace = FALSE){
 
     kv<-c(1,which(pset[i,]==1)+1)
     coef.vec[i,kv]<-m0$b
-    Xe<-model.matrix(formulae,data)
+    Xe<-stats::model.matrix(formulae,data)
     nvare<-dim(Xe)[2]
     K<-nvare
     if(family=="gaussian") K<-K+1
